# <span>ASIS: Artificial Intelligence Standard Software </span>

<p align="center">
    <strong><em>Open-Source AI Is Good for Us</em></strong>
</p>

> [!IMPORTANT]
> **Alpha March 15**

---

#### **Documentation**: <a href="https://asis/#" target="_blank">https://#</a>

#### **Source Code**: <a href="https://#" target="_blank">https://#</a>

---

We believe in open source AI to democratize technology, provide opportunities and development,
with established standards and rules, creating a transparent and competitive world for the benefit of all.

Asis is a set of standards,rules and framework for the deployment of an ecosystem of AI, based in "Personal AI", Concept analogous to personal computing and how it revolutionized the history of humanity.

## Main Features

<p>
    <em>Some of the main features of ASIS include:</em>
</p>

#### Assistant

---

| Feature              | Description                                                                                                                                       |
| -------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------- |
| **Personalized**     | Name, description, model llm, a Basic memory. (voice will be added in a future)                                                                   |
| **Choose the Model** | Model llm open source o commercial (More info bellow)                                                                                             |
| **Algorithms**       | create or download different algorithms for managing memory, generating agents and autonomous behaviors, manipulating data for the assistant, etc |
| **Agents**           | Agents pre instated for your assistant (5 agents will be dev in beta version)                                                                     |
| **Tools**            | Tools pre instated in your assistant, for revolve many problems through agents                                                                    |

#### Platform for development

---

| Feature            | Description                                                                                  |
| ------------------ | -------------------------------------------------------------------------------------------- |
| **Communication:** | Name, description, model llm, a memory,agents(voice agent will be added in a future release) |
| **Libraries**      | Model llm open source o commercial (More info bellow )                                       |

TODO::update this table

## Get started

> [!Note]
> This version only work in local mode

### **Create a Assistant**

#### What is a Entity AI?

A fundamental concept of ASIS is The AI ​​​​Entity, where each person, company, even space or place can be personified in a digital version, starting from a seed of a foundational model, where each of these is managed independently and personalized.

Basic Caracteristis:

- Memory long time
- Nickname
- Description
- Model (Model llm)
- Tools default
- Agents default

Examples:

- Michael is a makeup artist and his assistant, called "Mills", is his AI version, managing his clients' schedules, answering questions and calls, connecting with his friends' assistants to go out on weekends, exchanging work with his colleagues.

- John is the CEO of a start-up and "Bert" is the Ai of the company, managing Okrs and always helping employees, with doubts in his field, connecting with every employee assistant, keeping up with everything new, keeping an eye on cybersecurity, paying attention to employee complaints or problems, from the executive layer down.

- wally is an Ai, in charge of a residential building, in charge together with an agent of a security company, of making sure that everything is always safe, checking by cameras, sensors, entrances and more and together with the assistants of its residents, notifying arrivals of visitors as news about remodeling or changes in the rules of the building.

> [!IMPORTANT]
> This is only examples

**More information below**

Install:

```shell
$ pip install asis
```

```python
>>> Import asis as ASIS




```

Models available

### 🌐 Architecture

</a>
<details>
<summary>Assistant Architecture</summary>

![Assistant Architecture](/source/Frame1.png)

#### 🔨 System tools

These are tools by default:

- **Open stream:** Agent specialized for navigating the web, opening and working autonomously in programs.

- **Voice:** Personalize your assistant's voice, convert voices, and more.

- **Multimedia generator:** Agent specific for generating images and video, and modifying them.

- **Asis Chat:** Agent specific for chatting between assistants, exchanging information about patterns, schedules, and more, through a friend request.

> More tools will be added in the future

#### 💡 Memory

The memory of assistants will be managed by different algorithms for long-term and short-term storage of basic information.

> Images, videos, and more complicated algorithms will be added in the future.

#### :brain: Super Agent

The super agent is the main agent. It receives all the information from its environment, handles decisions, and communicates with the main model to solve complex problems in an autonomous and self-improving way.

#### 📖 Agents

An intelligent agent is an entity capable of perceiving its environment, processing such perceptions, and responding or acting in said environment in a rational manner to achieve objectives.

> We are interested in applying code from <a href=https://github.com/Significant-Gravitas/AutoGPT target="_blank">AutoGPT</a>, which is an open-source project for creating agents.

</details>

### Disclaimer

## Contribution and Roadmap

---

> [!Note]
> Coming soon

## Join our community

Discord

## License

[Apache License 2.0](LICENSE)
